==> shrinkwrap-resolver-api-maven-3.1.3-sources.jar: org/jboss/shrinkwrap/resolver/api/maven/strategy/TransitiveExclusionPolicy.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.shrinkwrap.resolver.api.maven.strategy;

import org.jboss.shrinkwrap.resolver.api.maven.ScopeType;

/**
 * Defines a policy for the handling of transitive dependencies during resolution.
 *
 * @author <a href="mailto:alr@jboss.org">Andrew Lee Rubinger</a>
 */
public interface TransitiveExclusionPolicy {

    /**
     * Whether or not optional transitive dependencies should be included during resolution
     *
     * @return Whether or not optional transitive dependencies should be included during resolution.
     */
    boolean allowOptional();

    /**
     * Returns the {@link ScopeType}s which should be filtered out of transitive dependencies and thus not included
     * during resolution.
     *
     * @return The {@link ScopeType}s.
     */
    ScopeType[] getFilteredScopes();

}

==> shrinkwrap-resolver-api-maven-3.3.4-sources.jar: org/jboss/shrinkwrap/resolver/api/maven/strategy/TransitiveExclusionPolicy.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.shrinkwrap.resolver.api.maven.strategy;

import org.jboss.shrinkwrap.resolver.api.maven.ScopeType;

/**
 * Defines a policy for the handling of transitive dependencies during resolution.
 *
 * @author <a href="mailto:alr@jboss.org">Andrew Lee Rubinger</a>
 */
public interface TransitiveExclusionPolicy {

    /**
     * Whether optional transitive dependencies should be included during resolution
     *
     * @return Whether optional transitive dependencies should be included during resolution.
     */
    boolean allowOptional();

    /**
     * Returns the {@link ScopeType}s which should be filtered out of transitive dependencies and thus not included
     * during resolution.
     *
     * @return The {@link ScopeType}s.
     */
    ScopeType[] getFilteredScopes();

}
